package com.quimodotcom.sendemailaction;

import com.stream_pi.action_api.actionproperty.property.*;
import com.stream_pi.action_api.externalplugin.NormalAction;
import com.stream_pi.util.exception.MinorException;
import com.stream_pi.util.version.Version;

import org.simplejavamail.email.EmailBuilder;
import org.simplejavamail.api.email.Email;
import org.simplejavamail.mailer.MailerBuilder;
import org.simplejavamail.api.mailer.Mailer;

import java.util.Arrays;
import java.util.List;

public class SendEmailAction extends NormalAction
{

    public SendEmailAction()
    {
        setName("Send Email");
        setCategory("Essentials");
        setAuthor("quimodotcom");
        setServerButtonGraphic("fas-terminal");
        setHelpLink("https://github.com/stream-pi/essentialactions");
        setVersion(new Version(0,9,3));

        hosts = Arrays.asList("smtp.gmail.com:465", "smtp-mail.outlook.com:587");
    }

    private final List hosts;

    @Override
    public void initProperties() throws MinorException
    {
        StringProperty recipientProperty = new StringProperty("recipient");
        recipientProperty.setDisplayName("Recipient");
        recipientProperty.setControlType(ControlType.TEXT_FIELD);

        StringProperty hostProperty = new StringProperty("smtphost");
        hostProperty.setDisplayName("Host Platform");
        hostProperty.setControlType(ControlType.COMBO_BOX);
        hostProperty.setListValue(hosts);

        Property sender = new StringProperty("sender");
        sender.setDisplayName("Sender Address");

        Property password = new StringProperty("password");
        password.setDisplayName("Sender Password");

        Property subject = new StringProperty("subject");
        subject.setDisplayName("Email Subject");

        Property message = new StringProperty("message");
        message.setDisplayName("Email Message");

        addClientProperties(recipientProperty, hostProperty, sender, password, subject, message);
    }

    @Override
    public void onActionClicked() throws MinorException
    {
        String recipient = getClientProperties().getSingleProperty("recipient").getStringValue();
        String[] hostDetails = getClientProperties().getSingleProperty("smtphost").getStringValue().split(":");
        String sender = getClientProperties().getSingleProperty("sender").getStringValue();
        String passwd = getClientProperties().getSingleProperty("password").getStringValue();
        String subject = getClientProperties().getSingleProperty("subject").getStringValue();
        String message = getClientProperties().getSingleProperty("message").getStringValue();

        Email email = EmailBuilder.startingBlank()
                .from("Stream-Pi", sender)
                .to("Recipient", recipient)
                .withSubject(subject)
                .withPlainText(message)
                .buildEmail();

        Mailer mailer = MailerBuilder
                .withSMTPServer(hostDetails[0], Integer.parseInt(hostDetails[1]), sender, passwd)
                .buildMailer();

        mailer.sendMail(email);
    }
}
